@@ -31,143 +31,217 @@ print("MPI size = ", size)
 
 
 def test_allreduce():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, token = Allreduce(arr, op=MPI.SUM)
+    res, token = allreduce(arr, op=MPI.SUM)
     assert jnp.array_equal(res, arr * size)
     assert jnp.array_equal(_arr, arr)
 
 
 def test_allreduce_jit():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res = jax.jit(lambda x: Allreduce(x, op=MPI.SUM)[0])(arr)
+    res = jax.jit(lambda x: allreduce(x, op=MPI.SUM)[0])(arr)
     assert jnp.array_equal(res, arr * size)
     assert jnp.array_equal(_arr, arr)
 
 
 def test_allreduce_scalar():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = 1
     _arr = 1
 
-    res, token = Allreduce(arr, op=MPI.SUM)
+    res, token = allreduce(arr, op=MPI.SUM)
     assert jnp.array_equal(res, arr * size)
     assert jnp.array_equal(_arr, arr)
 
 
 def test_allreduce_scalar_jit():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = 1
     _arr = 1
 
-    res = jax.jit(lambda x: Allreduce(x, op=MPI.SUM)[0])(arr)
+    res = jax.jit(lambda x: allreduce(x, op=MPI.SUM)[0])(arr)
     assert jnp.array_equal(res, arr * size)
     assert jnp.array_equal(_arr, arr)
 
 
 def test_allreduceT():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, _ = Allreduce(arr, op=MPI.SUM, _transpose=True)
+    res, _ = allreduce(arr, op=MPI.SUM, _transpose=True)
+    assert jnp.array_equal(_arr, res)
+
+
+def test_allreduceT_jit():
+    from mpi4jax import allreduce
+
+    arr = jnp.ones((3, 2))
+    _arr = arr.copy()
+
+    res, _ = jax.jit(lambda x: allreduce(x, op=MPI.SUM, _transpose=True))(arr)
     assert jnp.array_equal(_arr, res)
 
 
 def test_allreduce_transpose():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    (res,) = jax.linear_transpose(
-        lambda x: Allreduce(x, op=MPI.SUM, token=token)[0], arr
-    )(_arr)
+    (res,) = jax.linear_transpose(lambda x: allreduce(x, op=MPI.SUM)[0], arr)(_arr)
+    assert jnp.array_equal(_arr, res)
+
+
+def test_allreduce_transpose_jit():
+    from mpi4jax import allreduce
+
+    arr = jnp.ones((3, 2))
+    _arr = arr.copy()
+
+    def f(x):
+        (res,) = jax.linear_transpose(lambda x: allreduce(x, op=MPI.SUM)[0], arr)(x)
+        return res
+
+    res = jax.jit(f)(arr)
     assert jnp.array_equal(_arr, res)
 
 
 def test_allreduce_transpose2():
     # test transposing twice
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
     _arr2 = arr.copy()
 
     def lt(y):
-        return jax.linear_transpose(
-            lambda x: Allreduce(x, op=MPI.SUM, token=token)[0], arr
-        )(y)[0]
+        return jax.linear_transpose(lambda x: allreduce(x, op=MPI.SUM)[0], arr)(y)[0]
 
     (res,) = jax.linear_transpose(lt, _arr)(_arr2)
-    expected, _ = Allreduce(_arr2, op=MPI.SUM)
+    expected, _ = allreduce(_arr2, op=MPI.SUM)
+    assert jnp.array_equal(expected, res)
+
+
+def test_allreduce_transpose2_jit():
+    # test transposing twice
+    from mpi4jax import allreduce
+
+    arr = jnp.ones((3, 2))
+    _arr = arr.copy()
+    _arr2 = arr.copy()
+
+    def lt(y):
+        return jax.linear_transpose(lambda x: allreduce(x, op=MPI.SUM)[0], arr)(y)[0]
+
+    def f(x):
+        (res,) = jax.linear_transpose(lt, _arr)(x)
+        return res
+
+    res = jax.jit(f)(_arr2)
+    expected, _ = allreduce(_arr2, op=MPI.SUM)
     assert jnp.array_equal(expected, res)
 
 
 def test_allreduceT_transpose():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
     (res,) = jax.linear_transpose(
-        lambda x: Allreduce(x, op=MPI.SUM, token=token, _transpose=True)[0], arr
+        lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0], arr
     )(_arr)
-    expected, _ = Allreduce(_arr, op=MPI.SUM)
+    expected, _ = allreduce(_arr, op=MPI.SUM)
+    assert jnp.array_equal(expected, res)
+
+
+def test_allreduceT_transpose_jit():
+    from mpi4jax import allreduce
+
+    arr = jnp.ones((3, 2))
+    _arr = arr.copy()
+
+    def f(x):
+        (res,) = jax.linear_transpose(
+            lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0], arr
+        )(x)
+        return res
+
+    res = jax.jit(f)(_arr)
+    expected, _ = allreduce(_arr, op=MPI.SUM)
     assert jnp.array_equal(expected, res)
 
 
 def test_allreduceT_transpose2():
     # test transposing twice
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
     _arr2 = arr.copy()
 
     def lt(y):
         return jax.linear_transpose(
-            lambda x: Allreduce(x, op=MPI.SUM, token=token, _transpose=True)[0], arr
+            lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0], arr
         )(y)[0]
 
     (res,) = jax.linear_transpose(lt, _arr)(_arr2)
     assert jnp.array_equal(_arr2, res)
 
 
+def test_allreduceT_transpose2_jit():
+    # test transposing twice
+    from mpi4jax import allreduce
+
+    arr = jnp.ones((3, 2))
+    _arr = arr.copy()
+    _arr2 = arr.copy()
+
+    def lt(y):
+        return jax.linear_transpose(
+            lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0], arr
+        )(y)[0]
+
+    def f(x):
+        (res,) = jax.jit(jax.linear_transpose(lt, _arr))(x)
+        return res
+
+    res = jax.jit(f)(_arr2)
+    assert jnp.array_equal(_arr2, res)
+
+
 def test_allreduce_grad():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, grad = jax.value_and_grad(lambda x: Allreduce(x, op=MPI.SUM)[0].sum())(arr)
+    res, grad = jax.value_and_grad(lambda x: allreduce(x, op=MPI.SUM)[0].sum())(arr)
     assert jnp.array_equal(res, arr.sum() * size)
     assert jnp.array_equal(_arr, grad)
 
     res, grad = jax.jit(
-        jax.value_and_grad(lambda x: Allreduce(x, op=MPI.SUM)[0].sum())
+        jax.value_and_grad(lambda x: allreduce(x, op=MPI.SUM)[0].sum())
     )(arr)
     assert jnp.array_equal(res, arr.sum() * size)
     assert jnp.array_equal(_arr, grad)
 
     def testfun(x):
-        y, token = Allreduce(x, op=MPI.SUM)
+        y, token = allreduce(x, op=MPI.SUM)
         z = x + 2 * y  # noqa: F841
-        res, token2 = Allreduce(x, op=MPI.SUM, token=token)
+        res, token2 = allreduce(x, op=MPI.SUM)
         return res.sum()
 
     res, grad = jax.jit(jax.value_and_grad(testfun))(arr)
@@ -176,46 +250,41 @@ def test_allreduce_grad():
 
 
 def test_allreduce_jvp():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, jvp = jax.jvp(
-        lambda x: Allreduce(x, op=MPI.SUM, token=token)[0], (arr,), (_arr,)
-    )
+    res, jvp = jax.jvp(lambda x: allreduce(x, op=MPI.SUM)[0], (arr,), (_arr,))
 
-    expected, _ = Allreduce(arr, op=MPI.SUM)
+    expected, _ = allreduce(arr, op=MPI.SUM)
     assert jnp.array_equal(expected, res)
-    expected, _ = Allreduce(_arr, op=MPI.SUM)
+    expected, _ = allreduce(_arr, op=MPI.SUM)
     assert jnp.array_equal(expected, jvp)
 
 
 def test_allreduce_vjp():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, vjp_fun = jax.vjp(lambda x: Allreduce(x, op=MPI.SUM, token=token)[0], arr)
+    res, vjp_fun = jax.vjp(lambda x: allreduce(x, op=MPI.SUM)[0], arr)
     (vjp,) = vjp_fun(_arr)
 
-    expected, _ = Allreduce(arr, op=MPI.SUM)
+    expected, _ = allreduce(arr, op=MPI.SUM)
     assert jnp.array_equal(expected, res)
     assert jnp.array_equal(_arr, vjp)
 
 
 def test_allreduceT_jvp():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
     res, jvp = jax.jvp(
-        lambda x: Allreduce(x, op=MPI.SUM, token=token, _transpose=True)[0],
+        lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0],
         (arr,),
         (_arr,),
     )
@@ -224,24 +293,21 @@ def test_allreduceT_jvp():
 
 
 def test_allreduceT_vjp():
-    from mpi4jax import Allreduce
+    from mpi4jax import allreduce
 
-    token = jax.lax.create_token(123)
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
 
-    res, vjp_fun = jax.vjp(
-        lambda x: Allreduce(x, op=MPI.SUM, token=token, _transpose=True)[0], arr
-    )
+    res, vjp_fun = jax.vjp(lambda x: allreduce(x, op=MPI.SUM, _transpose=True)[0], arr)
     (vjp,) = vjp_fun(_arr)
 
     assert jnp.array_equal(arr, res)
-    expected, _ = Allreduce(_arr, op=MPI.SUM)
+    expected, _ = allreduce(_arr, op=MPI.SUM)
     assert jnp.array_equal(expected, vjp)
 
 
 def test_bcast():
-    from mpi4jax import Bcast
+    from mpi4jax import bcast
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
@@ -249,14 +315,14 @@ def test_bcast():
     if rank != 0:
         _arr = _arr * 0
 
-    res, token = Bcast(_arr, root=0)
+    res, token = bcast(_arr, root=0)
     assert jnp.array_equal(res, arr)
     if rank == 0:
         assert jnp.array_equal(_arr, arr)
 
 
 def test_bcast_jit():
-    from mpi4jax import Bcast
+    from mpi4jax import bcast
 
     arr = jnp.ones((3, 2))
     _arr = arr.copy()
@@ -264,14 +330,14 @@ def test_bcast_jit():
     if rank != 0:
         _arr = _arr * 0
 
-    res = jax.jit(lambda x: Bcast(x, root=0)[0])(arr)
+    res = jax.jit(lambda x: bcast(x, root=0)[0])(arr)
     assert jnp.array_equal(res, arr)
     if rank == 0:
         assert jnp.array_equal(_arr, arr)
 
 
 def test_bcast_scalar():
-    from mpi4jax import Bcast
+    from mpi4jax import bcast
 
     arr = 1
     _arr = 1
@@ -279,14 +345,14 @@ def test_bcast_scalar():
     if rank != 0:
         _arr = _arr * 0
 
-    res, token = Bcast(_arr, root=0)
+    res, token = bcast(_arr, root=0)
     assert jnp.array_equal(res, arr)
     if rank == 0:
         assert jnp.array_equal(_arr, arr)
 
 
 def test_bcast_scalar_jit():
-    from mpi4jax import Bcast
+    from mpi4jax import bcast
 
     arr = 1
     _arr = 1
@@ -294,7 +360,7 @@ def test_bcast_scalar_jit():
     if rank != 0:
         _arr = _arr * 0
 
-    res = jax.jit(lambda x: Bcast(x, root=0)[0])(_arr)
+    res = jax.jit(lambda x: bcast(x, root=0)[0])(_arr)
     assert jnp.array_equal(res, arr)
     if rank == 0:
         assert jnp.array_equal(_arr, arr)
@@ -302,53 +368,53 @@ def test_bcast_scalar_jit():
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
 
     if rank == 0:
         for proc in range(1, size):
-            res, token = Recv(arr, source=proc, tag=proc)
+            res, token = recv(arr, source=proc, tag=proc)
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
             assert jnp.array_equal(_arr, arr)
     else:
-        Send(arr, 0, tag=rank)
+        send(arr, 0, tag=rank)
         assert jnp.array_equal(_arr, arr)
 
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv_scalar():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = 1 * rank
     _arr = 1 * rank
 
     if rank == 0:
         for proc in range(1, size):
-            res, token = Recv(arr, source=proc, tag=proc)
+            res, token = recv(arr, source=proc, tag=proc)
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
             assert jnp.array_equal(_arr, arr)
     else:
-        Send(arr, 0, tag=rank)
+        send(arr, 0, tag=rank)
         assert jnp.array_equal(_arr, arr)
 
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv_scalar_jit():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = 1 * rank
     _arr = 1 * rank
 
     @jax.jit
     def send_jit(x):
-        Send(x, 0, tag=rank)
+        send(x, 0, tag=rank)
         return x
 
     if rank == 0:
         for proc in range(1, size):
-            res = jax.jit(lambda x: Recv(x, source=proc, tag=proc)[0])(arr)
+            res = jax.jit(lambda x: recv(x, source=proc, tag=proc)[0])(arr)
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
             assert jnp.array_equal(_arr, arr)
     else:
@@ -358,19 +424,19 @@ def test_send_recv_scalar_jit():
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv_jit():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
 
     @jax.jit
     def send_jit(x):
-        Send(x, 0, tag=rank)
+        send(x, 0, tag=rank)
         return x
 
     if rank == 0:
         for proc in range(1, size):
-            res = jax.jit(lambda x: Recv(x, source=proc, tag=proc)[0])(arr)
+            res = jax.jit(lambda x: recv(x, source=proc, tag=proc)[0])(arr)
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
             assert jnp.array_equal(_arr, arr)
     else:
@@ -380,19 +446,19 @@ def test_send_recv_jit():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_send_recv_deadlock():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     # this deadlocks without proper token management
     @jax.jit
     def deadlock(arr):
         if rank == 0:
             # send, then receive
-            token = Send(arr, 1)
-            newarr, _ = Recv(arr, 1, token=token)
+            token = send(arr, 1)
+            newarr, _ = recv(arr, 1, token=token)
         else:
             # receive, then send
-            newarr, token = Recv(arr, 0)
-            Send(arr, 0, token=token)
+            newarr, token = recv(arr, 0)
+            send(arr, 0, token=token)
         return newarr
 
     arr = jnp.ones(10) * rank
@@ -402,7 +468,7 @@ def test_send_recv_deadlock():
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv_status():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
@@ -410,31 +476,31 @@ def test_send_recv_status():
     if rank == 0:
         for proc in range(1, size):
             status = MPI.Status()
-            res, token = Recv(arr, source=proc, tag=proc, status=status)
+            res, token = recv(arr, source=proc, tag=proc, status=status)
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
             assert jnp.array_equal(_arr, arr)
             assert status.Get_source() == proc
     else:
-        Send(arr, 0, tag=rank)
+        send(arr, 0, tag=rank)
         assert jnp.array_equal(_arr, arr)
 
 
 @pytest.mark.skipif(size < 2, reason="need at least 2 processes to test send/recv")
 def test_send_recv_status_jit():
-    from mpi4jax import Recv, Send
+    from mpi4jax import recv, send
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
 
     @jax.jit
     def send_jit(x):
-        Send(x, 0, tag=rank)
+        send(x, 0, tag=rank)
         return x
 
     if rank == 0:
         for proc in range(1, size):
             status = MPI.Status()
-            res = jax.jit(lambda x: Recv(x, source=proc, tag=proc, status=status)[0])(
+            res = jax.jit(lambda x: recv(x, source=proc, tag=proc, status=status)[0])(
                 arr
             )
             assert jnp.array_equal(res, jnp.ones_like(arr) * proc)
@@ -447,14 +513,14 @@ def test_send_recv_status_jit():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
 
     other = 1 - rank
 
-    res, token = Sendrecv(arr, arr, source=other, dest=other)
+    res, token = sendrecv(arr, arr, source=other, dest=other)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
     assert jnp.array_equal(_arr, arr)
@@ -462,7 +528,7 @@ def test_sendrecv():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv_status():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
@@ -470,7 +536,7 @@ def test_sendrecv_status():
     other = 1 - rank
 
     status = MPI.Status()
-    res, token = Sendrecv(arr, arr, source=other, dest=other, status=status)
+    res, token = sendrecv(arr, arr, source=other, dest=other, status=status)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
     assert jnp.array_equal(_arr, arr)
@@ -479,7 +545,7 @@ def test_sendrecv_status():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv_status_jit():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
@@ -488,7 +554,7 @@ def test_sendrecv_status_jit():
 
     status = MPI.Status()
     res = jax.jit(
-        lambda x, y: Sendrecv(x, y, source=other, dest=other, status=status)[0]
+        lambda x, y: sendrecv(x, y, source=other, dest=other, status=status)[0]
     )(arr, arr)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
@@ -498,14 +564,14 @@ def test_sendrecv_status_jit():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv_scalar():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = 1 * rank
     _arr = arr
 
     other = 1 - rank
 
-    res, token = Sendrecv(arr, arr, source=other, dest=other)
+    res, token = sendrecv(arr, arr, source=other, dest=other)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
     assert jnp.array_equal(_arr, arr)
@@ -513,14 +579,14 @@ def test_sendrecv_scalar():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv_jit():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = jnp.ones((3, 2)) * rank
     _arr = arr.copy()
 
     other = 1 - rank
 
-    res = jax.jit(lambda x, y: Sendrecv(x, y, source=other, dest=other)[0])(arr, arr)
+    res = jax.jit(lambda x, y: sendrecv(x, y, source=other, dest=other)[0])(arr, arr)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
     assert jnp.array_equal(_arr, arr)
@@ -528,14 +594,14 @@ def test_sendrecv_jit():
 
 @pytest.mark.skipif(size < 2 or rank > 1, reason="Runs only on rank 0 and 1")
 def test_sendrecv_scalar_jit():
-    from mpi4jax import Sendrecv
+    from mpi4jax import sendrecv
 
     arr = 1 * rank
     _arr = arr
 
     other = 1 - rank
 
-    res = jax.jit(lambda x, y: Sendrecv(x, y, source=other, dest=other)[0])(arr, arr)
+    res = jax.jit(lambda x, y: sendrecv(x, y, source=other, dest=other)[0])(arr, arr)
 
     assert jnp.array_equal(res, jnp.ones_like(arr) * other)
     assert jnp.array_equal(_arr, arr)
@@ -562,6 +628,19 @@ def run_in_subprocess(code, test_file, timeout=10):
 
     test_file.write_text(cov_preamble + code)
 
+    # passing a mostly empty env seems to be the only way to
+    # force MPI to initialize again
+    env = dict(
+        PATH=os.getenv("PATH", ""),
+        COVERAGE_PROCESS_START="pyproject.toml",
+        XLA_PYTHON_CLIENT_PREALLOCATE="false",
+        LD_LIBRARY_PATH=os.getenv("LD_LIBRARY_PATH", ""),
+    )
+
+    # non-standard Intel MPI env var for libfabric.
+    if "FI_PROVIDER_PATH" in os.environ:
+        env["FI_PROVIDER_PATH"] = os.getenv("FI_PROVIDER_PATH")
+
     proc = subprocess.run(
         [sys.executable, test_file],
         stdout=subprocess.PIPE,
@@ -569,13 +648,7 @@ def run_in_subprocess(code, test_file, timeout=10):
         bufsize=0,
         timeout=timeout,
         universal_newlines=True,
-        # passing a mostly empty env seems to be the only way to
-        # force MPI to initialize again
-        env=dict(
-            PATH=os.environ["PATH"],
-            COVERAGE_PROCESS_START="pyproject.toml",
-            XLA_PYTHON_CLIENT_PREALLOCATE="false",
-        ),
+        env=env,
     )
     return proc
 
@@ -592,7 +665,7 @@ def test_abort_on_error(tmp_path):
         import jax.numpy as jnp
 
         from mpi4py import MPI
-        from mpi4jax import Send
+        from mpi4jax import send
 
         comm = MPI.COMM_WORLD
         assert comm.Get_size() == 1
@@ -600,7 +673,7 @@ def test_abort_on_error(tmp_path):
         # send to non-existing rank
         @jax.jit
         def send_jit(x):
-            Send(x, dest=100, comm=comm)
+            send(x, dest=100, comm=comm)
 
         send_jit(jnp.ones(10))
     """
@@ -624,14 +697,14 @@ def test_deadlock_on_exit(tmp_path):
         import jax.numpy as jnp
 
         from mpi4py import MPI
-        from mpi4jax import Sendrecv
+        from mpi4jax import sendrecv
 
         comm = MPI.COMM_WORLD
         assert comm.Get_size() == 1
 
         # sendrecv to self
         jax.jit(
-            lambda x: Sendrecv(sendbuf=x, recvbuf=x, source=0, dest=0, comm=comm)[0]
+            lambda x: sendrecv(sendbuf=x, recvbuf=x, source=0, dest=0, comm=comm)[0]
         )(jnp.ones(10))
     """
     )
@@ -641,19 +714,19 @@ def test_deadlock_on_exit(tmp_path):
 
 
 def test_set_debug_logging(capsys):
-    from mpi4jax import Allreduce
-    from mpi4jax.cython.mpi_xla_bridge import set_logging
+    from mpi4jax import allreduce
+    from mpi4jax._src.cython.mpi_xla_bridge import set_logging
 
     arr = jnp.ones((3, 2))
     set_logging(True)
-    res = jax.jit(lambda x: Allreduce(x, op=MPI.SUM)[0])(arr)
+    res = jax.jit(lambda x: allreduce(x, op=MPI.SUM)[0])(arr)
     res.block_until_ready()
 
     captured = capsys.readouterr()
     assert captured.out.startswith(f"r{rank} | MPI_Allreduce with token")
 
     set_logging(False)
-    res = jax.jit(lambda x: Allreduce(x, op=MPI.SUM)[0])(arr)
+    res = jax.jit(lambda x: allreduce(x, op=MPI.SUM)[0])(arr)
     res.block_until_ready()
 
     captured = capsys.readouterr()
